---
title: <span class="badge object-type-scalar"></span> KiloAmpere
---
# <span class="badge object-type-scalar"></span> KiloAmpere

Energy: Kiloampere (kA)

## Definition

```python
# Energy: Kiloampere (kA)
KiloAmpere: typing.Literal["kamp"] = "kamp"
```
